0  'FILENAME: "CAL"  (for "Calendrics").
10 'PURPOSE:   Calendrical computations and conversions, European and Mayan,
20 '           with lunar and planetary correlates.
30 'PROGRAM in MBASIC, written at intervals during the summer of 1983,
40 '           by F. G. Lounsbury.  Revised July 1984.
45 ' Corrections made to 7(+dn) & 8(-dn) by Lewis A Newbill. July 1987
50 ' Corrections made to 1(-dn) by Lewis A. Newbill, December 1987
60 '
90 DIM CH$(255)
91 CLS
92 WIDTH LPRINT 84
99 '
100 '==========================================================================
101 'TABLE OF CONTENTS:
102 '   Print options; Input options .................................... 200
103 '   Longcount date (LC)  ======>  Julian day number ................. 300
104 '   Calendar-round day (CR)  ==>  Julian day number ................. 400
105 '   Ring-based date (RD)  =====>  Julian day number ................. 500
106 '   Serpent date (SD)  ========>  Julian day number ................. 600
107 '   European date (EUR: J/G) ==>  Julian day number ................. 700
108 '   Direct input of Julian day number (JD) .......................... 800
110 '   Subroutine:  Maya numeral (MN), segmentation and evaluation .... 1000
111 '   Subroutine:  Maya addition, subtraction, and multiplication .... 1100
112 '   Distance number (+/- DN), applied to LC and/or CR .............. 1200
113 '   Julian day number  ==>  Longcount date ......................... 1300
114 '   Julian day number  ==>  Calendar-round day ..................... 1400
115 '   Julian day number  ==>  Julian and Gregorian dates ............. 1500
116 '   Subroutine:  Year-day  ==>  Month and Month-day ................ 1600
120 '   Moon age, abnodal interval, eclipse possibilities .............. 2000
121 '   819-day station ................................................ 2100
122 '   Venus .......................................................... 2200
123 '   Jupiter ........................................................ 2300
124 '   Saturn ......................................................... 2400
125 '   Mars ........................................................... 2500
126 '   Mercury ........................................................ 2600
130 '   Print routines ................................................. 3000
131 '   Text entry ..................................................... 3100
132 '   Coda ........................................................... 3200
199 '
200 '==========================================================================
201 '                    Print Options, and Input Options.
202 '                          Variables:  PR, IP.
203 '
210 PRINT STRING$(78,45)
215 PRINT"DATA SOURCE:   Enter  1  if from KEYBOARD,  or  2  if from DATAFILE."
220 INPUT IP
225 IF IP<>2 THEN 255
230 '
235 INPUT"Enter name (including drive) of Source File for data input:     ":IF$
240 OPEN "I",#1,IF$
245 GOTO 255
250 '
255 PRINT STRING$(78,45)
260 PRINT"PRINT OPTIONS:  Enter  1  for SCREEN,  2  for PRINTER,  or  3  for DISK."
265 INPUT PR
270 IF PR<>3 THEN 300
275 '
280 INPUT "Enter desired name (including DRIVE:) of Output File:     ";OF$
285 OPEN "O",#2,OF$
290 GOTO 300
295 '
300 PRINT STRING$(78,45)
305 PRINT "DATA TYPE:  Enter  1  if LC,   2  if CR,   3  if EUR,   4  if JDN,"
310 PRINT "                   5  if RD,   6  if SD,   7  if +DN,   8  if -DN,"
315 PRINT "                   9  if TXT,  10 to DOS,  11 to MAYACAL."
320 '
325 INPUT DTTP:  ON DTTP GOTO 335,580,1125,1285,845,1040,1665,1665,2870,3090,3085
330 '
335 '--------------------------------------------------------------------------
340 '    Input of Maya Longcount date, and conversion to Julian Day Number.
345 '         Input variable:      LC$ (Longcount numeral, without periods).
350 '         Subroutine variable: MN$ (Maya numeral).
355 '         Intermediate variables:  see subroutine 1000 ff.
360 '         Output variables:    LC$ (Longcount numeral, with periods);
365 '                              MD# (Maya day number, Arabic notation);
370 '                              JD# (Julian day number).
375 PRINT STRING$(78,45)
380 PRINT"Enter the five (or fewer) LC digits, separated by single spaces [no periods],"
385 PRINT STRING$(40,32)+"----or press RETURN for other options."
390 '
395 INPUT LC$
400 IF LC$="" THEN 3055
405 IF MID$(LC$,1,2)="- " THEN MID$(LC$,1,2)=" -"
410 '
415 MN$=LC$       '[Assignment of LC$ to subroutine variable.]
420   GOSUB 1480
425 LC$=MN$       '[MN$ back from subroutine, with period place markers.]
430 MD#=MN#       '[MN# computed in subroutine.]
435 JD#=MD#+584285!
440   GOTO 1895
445 '
450 PRINT: PRINT STRING$(78,45)
455 PRINT"If a DN is to be applied to this date,"
460 PRINT STRING$(18,32);
465 PRINT "then enter its sign (+ or -) and the DN (without periods)."
466 PRINT " OMIT LEADING ZEROES FOR -DN CALCULATION "
470 PRINT"----Otherwise, press \ and RETURN  to enter another LC,"
475 PRINT"        ----Or, just press RETURN  to recall other options."
480 '
485 LINE INPUT DN$
490 IF DN$="\" THEN 335 ELSE IF DN$="" THEN 3055 ELSE 495
495 IF MID$(DN$,1,2)="- " THEN MID$(DN$,1,2)=" -"
500 IF MID$(DN$,1,2)="+ " THEN MID$(DN$,1,2)=" +"
505 '
510 MN$=DN$
515   GOSUB 1470
520 DN$=MN$
525 DN#=MN#
530 JD#=JD#+DN#
535 '
540 ON PR GOTO 545,555,545
545 PRINT DN$
550   IF PR=1 THEN 570 ELSE 565
555 LPRINT DN$
560   GOTO 570
565 PRINT#2,DN$
570   GOTO 1890
575 '
580 '--------------------------------------------------------------------------
585 '  Input of Maya Calendar-Round date, and conversion to Julian Day Number.
590 '        Variables:   CR$;   VEINT$, HAAB$;   X, RT$;  SP1-5, L1-6; 
595 '        T$, T;  V$, V1$, VLOC, V;  DD$, DD;  MM$, MM1$, MMLOC, MM;
600 '        BT$, BT;   KT$, KT;   DT, DV, DZ, DH, NH, DCR, NCR;   JD#.
605 '
610 X=0   '[for counting repetitions of run;  cf. lines 487, 490, and 1945.]
615 '
620 VEINT$="imiImiIMIik!Ik!IK!akbAkbAKBkanKanKANchiChiCHIcimCimCIMmanManMANlamLamLAMmulMulMULoc!Oc!OC!chuChuCHUeb!Eb!EB!benBenBENix!Ix!IX!menMenMENcibCibCIBcabCabCABetzEtzETZcauCauCAUahaAhaAHA"
625 HAAB$="popPopPOPuo!Uo!UO!zipZipZIPzotZotZOTtzeTzeTZExulXulXULyxkYxkYXKmolMolMOLcheCheCHEyaxYaxYAXzacZacZACcehCehCEHmacMacMACkanKanKANmuaMuaMUApaxPaxPAXkayKayKAYcumCumCUMuayUayUAY"
630 '
635 RT$=""    '[to clear the series-terminating "\" of lines 491-493.]
640 PRINT STRING$(78,45)
645 PRINT"Enter the CR  [with or without estimated Baktun & Katun digits (no punctuation)]"
650 PRINT STRING$(41,32)+"----or press RETURN for other options."
655 INPUT CR$:  IF CR$="" THEN 3055
660 '
665 SP1=INSTR(CR$," "):  SP2=INSTR(SP1+2,CR$," "):  SP3=INSTR(SP2+2,CR$," ")
670 SP4=INSTR(SP3+2,CR$," "): SP5=INSTR(SP4+2,CR$," ")
675 L1=SP1-1:  L2=SP2-SP1-1:  L3=SP3-SP2-1
680 IF SP4=0 THEN L4=LEN(CR$)-SP3  ELSE L4=SP4-SP3-1
685 '
690 T$=LEFT$(CR$,L1):  T=VAL(T$):  V$=MID$(CR$,SP1+1,L2)
695 IF LEN(V$)<3 THEN V$=V$+"!"
700 V1$=LEFT$(V$,3)
705 VLOC=INSTR(VEINT$,V1$):  V=((VLOC\9)+1) MOD 20
710 '
715 DD$=MID$(CR$,SP2+1,L3):  DD=VAL(DD$):  MM$=MID$(CR$,SP3+1,L4)
720 IF MM$="zec" OR MM$="Zec" OR MM$="ZEC" THEN MM$="TZEC"
725 IF MM$="yaxkin" OR MM$="Yaxkin" OR MM$="YAXKIN" THEN MM$="YXK"
730 IF LEN(MM$)<3 THEN MM$=MM$+"!"
735 MM1$=LEFT$(MM$,3)
740 MMLOC=INSTR(HAAB$,MM1$):  MM=(MMLOC\9)+1
745 '
750 IF SP4=0 THEN BT=8: KT=12: GOTO 770
755 L5=SP5-SP4-1:  L6=LEN(CR$)-SP5
760 BT$=MID$(CR$,SP4+1,L5): BT=VAL(BT$): KT$=MID$(CR$,SP5+1,L6): KT=VAL(KT$)
765 '
770 DT=T-4: DV=V
775 DZ=(40*DT-39*DV) MOD 260: IF DZ<0 THEN DZ=DZ+260
780 DH=(20*(MM-1)+DD+17) MOD 365: IF DH<0 THEN DH=DH+365
785 NH=(DZ-DH) MOD 52: IF NH<0 THEN NH=NH+52
790 DCR=365*NH+DH
795 NCR=INT(((20*BT+KT)*7200)/18980)-2   '[The -2 is to center the expected LC]
800 JD#=(NCR*18980)+DCR+584285!
805 IF X=5 THEN 815 ELSE 835
810 '
815 PRINT STRING$(78,45)
820 PRINT"----Stopped for viewing.  Press RETURN to continue,":  X=0
825 PRINT STRING$(28,32)+"--or press  \ and RETURN  to terminate this series."
830 LINE INPUT RT$
835 IF RT$="\" THEN 635
840 GOTO 1870
845 '--------------------------------------------------------------------------
850 ' Input of numbers for Maya 'Ring' date, and conversion to Longcount date.
855 '         Input variables:  RN$ (ring number)
860 '                           CN$ (companion number)
865 '
870 PRINT STRING$(78,45)
875 '
880 PRINT"Enter CN (5 digits, separated by single spaces)  --or RETURN for other options"
885 INPUT CN$
890 IF CN$="" THEN 3055
895 MN$=CN$       '[Assignment of CN$ to subroutine variable.]
900   GOSUB 1480
905 CN$=MN$       '[MN$ back from subroutine.]
910 CN#=MN#       '[MN# computed in subroutine.]
915 C5=N5: C4=N4: C3=N3: C2=N2: C1=N1
920 '
925 PRINT "Enter RN (appropriate number of digits, with spaces)"
930 INPUT RN$
935 MN$=RN$       '[Assignment of RN$ to subroutine variable
940   GOSUB 1480
945 RN$=MN$       '[MN$ back from subroutine.]
950 RN#=MN#       '[MN(#) computed in subroutine.]
955 R5=N5: R4=N4: R3=N3: R2=N2: R1=N1
960 '
965 MD#=CN#-RN#: JD#=MD#+584285!
970 IF C1<R1 THEN C1=C1+20: C2=C2-1
975 IF C2<R2 THEN C2=C2+18: C3=C3-1
980 IF C3<R3 THEN C3=C3+20: C4=C4-1
985 IF C4<R4 THEN C4=C4+10: C5=C5-1
990 N5=C5-R5: N5$=STR$(N5)+".": N5$=MID$(N5$,2,LEN(N5$)-1)
995 N4=C4-R4: N4$=STR$(N4)+".": N4$=MID$(N4$,2,LEN(N4$)-1)
1000 N3=C3-R3: N3$=STR$(N3)+".": N3$=MID$(N3$,2,LEN(N3$)-1)
1005 N2=C2-R2: N2$=STR$(N2)+".": N2$=MID$(N2$,2,LEN(N2$)-1)
1010 N1=C1-R1: N1$=STR$(N1):     N1$=MID$(N1$,2,LEN(N1$)-1)
1015 LC$=N5$+N4$+N3$+N2$+N1$
1020 PRINT
1025 PRINT CN$" (CN) - "RN$" (RN) = "LC$" (LC)."
1030 GOTO 1870
1035 '
1040 '--------------------------------------------------------------------------
1045 '      Input of Maya Serpent Date and conversion to Julian Day Number.
1050 '
1055 '
1060 PRINT STRING$(78,45)
1065 PRINT"Enter Serpent Number (6 Maya digits, separated by spaces [not periods]),"
1070 PRINT STRING$(41,32)+"----or press RETURN for other options."
1075 INPUT SN$
1080 IF SN$="" THEN 3055
1085 MN$=SN$       '[Assignment of SN$ to subroutine variable.]
1090   GOSUB 1480
1095 SN$=MN$       '[MN$ back from subroutine, with period place markers.]
1100 JD#=MN#-10967536#+584285!       '[Maya 3.16.3.5.6.16 = 10967536.]
1105 PRINT: PRINT "Serpent Date "SN$;
1110 PRINT USING " (########) = the following:";MN#
1115   GOTO 1870
1120 '
1125 '--------------------------------------------------------------------------
1130 '  Input of Julian or Gregorian date, and conversion to Julian Day Number.
1135 '       Input variable:  JG$ (Julian/Gregorian date)
1140 '       Constant data:   Z$ (the Months, with their zero-day numbers)
1145 '       Derived variables:  Y$, Y (year);  M$, M (month);  D$, D (day);
1150 '                           CAL$ (the calendar: Julian or Gregorian).
1155 '
1165 Z$="janJanJAN000febFebFEB031marMarMAR059aprAprAPR090mayMayMAY120junJunJUN151julJulJUL181augAugAUG212sepSepSEP243octOctOCT273novNovNOV304decDecDEC334"
1170 '
1175 PRINT STRING$(78,45)
1180 PRINT"Enter the YEAR and MONTH and DAY and J or G (for Julian/Gregorian) [no commas;use spaces],"
1185 PRINT STRING$(40,32)+"-----or press RETURN for other options."
1190 INPUT JG$: IF JG$="" THEN 3055
1195 SP1=INSTR(JG$," "):  SP2=INSTR(SP1+1,JG$," "):  SP3=INSTR(SP2+1,JG$," ")
1200 LY=SP1-1:  LM=SP2-SP1-1:  LD=SP3-SP2-1
1205 Y$=LEFT$(JG$,LY):  M$=LEFT$(MID$(JG$,SP1+1,LM),3):  D$=MID$(JG$,SP2+1,LD)
1210 Y=VAL(Y$):  D=VAL(D$):   CAL$=RIGHT$(JG$,1)
1215 MLOC=INSTR(Z$,M$)\12: M=MLOC+1: ZLOC=MLOC*12+10: MZ$=MID$(Z$,ZLOC,3)
1220 MZ$=MID$(Z$,ZLOC,3): MZ=VAL(MZ$)
1225 IF CAL$="g" THEN CAL$="G"
1230 IF CAL$="j" THEN CAL$="J"
1235 '
1240 Q=Y/4:  IF (Q-INT(Q)=0)*(M<3) THEN MZ=MZ-1
1245 JD#=INT((Y+4712)*365.25)+MZ+D
1250 DS=INT(Y/100)-2
1255 GR=INT(DS*.75+.25)
1260 IF (Y MOD 100=0)*(Y MOD 400<>0)*(CAL$="J")*(M<3) THEN GR=GR-1
1265 IF (Y MOD 100=0)*(Y MOD 400<>0)*(CAL$="G")*((MZ+D)<60) THEN GR=GR-1
1270 IF CAL$="G" THEN JD#=JD#-GR
1275 GOTO 1870
1280 '
1285 '--------------------------------------------------------------------------
1290 '   Input of Julian Day Number, as single item or as starter for series.
1295 '                    Variables:  JD#, QD#, S, IV, N, L.
1300 '
1305 PRINT "SINGLE ITEM or SERIES?    Enter  1  for SINGLE,  or  2  for SERIES."
1310 INPUT S: ON S GOTO 1315,1325
1315 PRINT "INPUT:  Julian day number."
1320 INPUT JD#: GOTO 1870
1325 PRINT"INPUT:  Julian day number, mean interval, and desired number in series."
1330 INPUT QD#,IV,N
1335 L=0: X=0
1340 JD#=QD#: GOTO 1870
1345 IF X=N THEN 3055
1350 QD#=QD#+IV
1355 JD#=INT(QD#+.5)
1360 L=L+4
1365 IF (PR=1)*(L>16) THEN 1370 ELSE 1385
1370 PRINT STRING$(25,45)+"Stopped for viewing.  Press RETURN to continue.": L=0
1375 LINE INPUT LI$
1380 IF LI$="" THEN 1870
1385 IF (PR=2)*(L>53) THEN 1390 ELSE 1870
1390 PRINT "Stopped for page break.  Type CONT to continue.": STOP: L=0
1395 '
1400      GOTO 1445
1405 '
1410 '--------------------------------------------------------------------------
1415 PRINT "Enter Julian Day Number."
1420 PRINT "   Optionally (after a single space) an interval leading to another date"
1425 PRINT "      may also be entered."
1430 PRINT "   And as a further option, if repeated applications of the interval are"
1435 PRINT "      desired, the number of applications may be entered (after another space)."
1440 PRINT "   ---------------------- or press RETURN for other options.
1445 '-------------------------------------------------------------------------
1450 '       Subroutine:  Segmentation and Evaluation of Maya Numerals.
1455 '        Entering variable:  MN$ (Maya numeral, without periods).
1460 '
1465 '
1470 IF MID$(MN$,LEN(MN$),1)=" " THEN MN$=MID$(MN$,1,LEN(MN$)-1): GOTO 1470
1475 '
1480 DIV5=INSTR(MN$," ")
1485 DIV4=INSTR(DIV5+1,MN$," ")
1490 DIV3=INSTR(DIV4+1,MN$," ")
1495 DIV2=INSTR(DIV3+1,MN$," ")
1500 DIV1=INSTR(DIV2+1,MN$," ")
1505 '
1510 IF DIV5=0 THEN DIV1=0: DIV2=0: DIV3=0: DIV4=0: GOTO 1540
1515 IF DIV4=0 THEN DIV1=DIV5: DIV2=0: DIV3=0: DIV5=0: GOTO 1540
1520 IF DIV3=0 THEN DIV1=DIV4: DIV2=DIV5: DIV4=0: DIV5=0: GOTO 1540
1525 IF DIV2=0 THEN DIV1=DIV3: DIV2=DIV4: DIV3=DIV5: DIV4=0: DIV5=0: GOTO 1540
1530 IF DIV1=0 THEN DIV1=DIV2: DIV2=DIV3: DIV3=DIV4: DIV4=DIV5:DIV5=0:GOTO 1540
1535 '
1540 LN1=LEN(MN$)-DIV1
1545 IF DIV1>0 THEN LN2=DIV1-DIV2-1 ELSE LN2=0
1550 IF DIV2>0 THEN LN3=DIV2-DIV3-1 ELSE LN3=0
1555 IF DIV3>0 THEN LN4=DIV3-DIV4-1 ELSE LN4=0
1560 IF DIV4>0 THEN LN5=DIV4-DIV5-1 ELSE LN5=0
1565 IF DIV5>0 THEN LN6=DIV5-1 ELSE LN6=0
1570 '
1575 N6$=LEFT$(MN$,LN6): N6=VAL(N6$): IF N6$>"" THEN N6$=N6$+"."
1580 N5$=MID$(MN$,DIV5+1,LN5): N5=VAL(N5$): IF N5$>"" THEN N5$=N5$+"."
1585 N4$=MID$(MN$,DIV4+1,LN4): N4=VAL(N4$): IF N4$>"" THEN N4$=N4$+"."
1590 N3$=MID$(MN$,DIV3+1,LN3): N3=VAL(N3$): IF N3$>"" THEN N3$=N3$+"."
1595 N2$=MID$(MN$,DIV2+1,LN2): N2=VAL(N2$): IF N2$>"" THEN N2$=N2$+"."
1600 N1$=RIGHT$(MN$,LN1): N1=VAL(N1$)
1605 '
1610 IF N6<0 THEN N5=-N5:N4=-N4:N3=-N3:N2=-N2:N1=-N1: GOTO 1635
1615 IF N5<0 THEN N4=-N4:N3=-N3:N2=-N2:N1=-N1: GOTO 1635
1620 IF N4<0 THEN N3=-N3:N2=-N2:N1=-N1: GOTO 1635
1625 IF N3<0 THEN N2=-N2:N1=-N1: GOTO 1635
1630 IF N2<0 THEN N1=-N1
1635 '
1640 MN$=N6$+N5$+N4$+N3$+N2$+N1$
1645 MN#=(8000*N6+400*N5+20*N4+N3)*360+20*N2+N1
1650 '
1655 RETURN
1660 '
1665 '-------------------------------------------------------------------------
1670 '   Input of Distance Number, leading from anterior to posterior LC date.
1675 '            Variables:  N5, N4, N3, N2, N1; D5, D4, D3, D2, D1.
1680 '
1681 IP=DTTP
1685 PRINT "Is the Distance Number applicable to the last date?"
1690 INPUT "    If yes, enter  Y ;  if no,  N .    ";Y$
1695 IF Y$="Y" OR Y$="y" THEN 1715
1700 PRINT "If DN is applicable to a different date, then enter that date"
1705 PRINT "    ( 5 digits,  with 4 commas ):"
1710 INPUT N5,N4,N3,N2,N1
1715 PRINT "Enter the Distance Number ( 5  digits,  4 commas ):"
1720 INPUT D5,D4,D3,D2,D1
1725 IF IP=7 THEN SIGN$="+" ELSE IF IP=8 THEN SIGN$="-"
1730 IF PR=2 THEN 1760
1735 PRINT: PRINT USING "##.";N5;N4;N3;N2;
1740 PRINT USING "## (anterior date) ";N1;:PRINT USING "\ \";SIGN$;
1745 PRINT USING "##.";D5;D4;D3;D2;
1750 PRINT USING "## (DN)  =  the following date:";D1
1755 GOTO 1780
1760 LPRINT: LPRINT USING "##.";N5;N4;N3;N2;
1765 LPRINT USING "## (anterior date) ";N1;:LPRINT USING "\ \";SIGN$;
1770 LPRINT USING "##.";D5;D4;D3;D2;
1775 LPRINT USING "## (DN)  =  the following date:";D1
1780 IF IP=7 THEN 1815
1785 IF N1<D1 THEN N1=N1+20: N2=N2-1
1790 IF N2<D2 THEN N2=N2+18: N3=N3-1
1795 IF N3<D3 THEN N3=N3+20: N4=N4-1
1800 IF N4<D4 THEN N4=N4+20: N5=N5-1
1805 N5=N5-D5: N4=N4-D4: N3=N3-D3: N2=N2-D2: N1=N1-D1
1810 GOTO 1856
1815 N1=N1+D1
1820 IF N1>19 THEN N1=N1-20: N2=N2+1
1825 N2=N2+D2
1830 IF N2>17 THEN N2=N2-18: N3=N3+1
1835 N3=N3+D3
1840 IF N3>19 THEN N3=N3-20: N4=N4+1
1845 N4=N4+D4
1850 IF N4>19 THEN N4=N4-20: N5=N5+1
1855 N5=N5+D5
1856 IF PR=2 THEN LPRINT USING "##.";N5;N4;N3;N2;N1 ELSE PRINT USING "##.";N5;N4;N3;N2;N1
1860 GOTO 385
1865 '
1870 '-------------------------------------------------------------------------
1875 '         Conversion of Julian Day Number to Maya Longcount Date.
1880 '            Variables:  JD#, MD#, RM, N5, N4, N3, N2, N1, G.
1885 '
1890 MD#=JD#-584285!
1895 N5=INT(MD#/144000!): RM=MD#-N5*144000!
1900 N4=INT(RM/7200): RM=RM-N4*7200
1905 N3=INT(RM/360): RM=RM-N3*360
1910 N2=INT(RM/20): N1=RM-N2*20
1915 G=(2*N2+N1) MOD 9: IF G<1 THEN G=G+9
1920 G$="  G"+RIGHT$(STR$(G),1)+".  "
1925 '
1930 IF (MD#=0 OR N5<0) THEN N5=N5+13: N5$="OLD ERA"+STR$(N5)+".": GOTO 1940
1935 N5$=STR$(N5)+".":  N5$=MID$(N5$,2,LEN(N5$)-1)    'Second clause is to
1940 N4$=STR$(N4)+".":  N4$=MID$(N4$,2,LEN(N4$)-1)    'eliminate preposed space
1945 N3$=STR$(N3)+".":  N3$=MID$(N3$,2,LEN(N3$)-1)    'which is carried over
1950 N2$=STR$(N2)+".":  N2$=MID$(N2$,2,LEN(N2$)-1)    'into string variable
1955 N1$=STR$(N1)+",":  N1$=MID$(N1$,2,LEN(N1$)-1)    'from numeric variable.
1960 LC$=N5$+N4$+N3$+N2$+N1$
1965 '
1970 '
1975 '-------------------------------------------------------------------------
1980 '      Conversion of Julian Day Number to Maya Calendar-Round Date.
1985 '            Variables:  JD#, MD#, T, V, V$, H, MM, MM$, DD.
1990 '
1995 T=MD#+4-(13*INT((MD#+4)/13)): IF T<1 THEN T=T+13
2000 T$=STR$(T)
2005 V=MD#-(20*INT(MD#/20)): V$=STR$(V)
2010 H=MD#-17-(365*INT((MD#-17)/365))
2015 MM=INT(H/20): MM$=STR$(MM)
2020 DD=H-20*MM
2025 DD$=STR$(DD)
2030 '
2035 DAYS$="0Ahau 1Imix 2Ik 3Akbal 4Kan 5Chicchan 6Cimi 7Manik 8Lamat 9Muluc 10Oc 11Chuen 12Eb 13Ben 14Ix 15Men 16Cib 17Caban 18Etznab 19Cauac "
2040 LOCV=INSTR(DAYS$,V$)+1
2045 FINV=INSTR(LOCV+1,DAYS$," ")
2050 IF V<10 THEN LVN=1 ELSE LVN=2
2055 LNV=FINV-LOCV-LVN
2060 V$=MID$(DAYS$,LOCV+LVN,LNV)
2065 '
2070 MONTHS$="0Pop 1Uo 2Zip 3Zotz 4Tzec 5Xul 6Yaxkin 7Mol 8Chen 9Yax 10Zac 11Ceh 12Mac 13Kankin 14Muan 15Pax 16Kayab 17Cumhu 18Uayeb "
2075 LOCMM=INSTR(MONTHS$,MM$)+1
2080 FINMM=INSTR(LOCMM+1,MONTHS$," ")
2085 IF MM<10 THEN LMN=1 ELSE LMN=2
2090 LNMM=FINMM-LOCMM-LMN
2095 MM$=MID$(MONTHS$,LOCMM+LMN,LNMM)
2100 '
2105 CR$=T$+" "+V$+DD$+" "+MM$+"."
2110 '
2115 '-------------------------------------------------------------------------
2120 ' Conversion of Julian Day Number to Julian and Gregorian Calendar Dates.
2125 '             Variables:  JD#, CD#, Y, RD, LJ, YD, M$, D;
2130 '                          DS, GR, LG, GY, GYD, GM$, GD.
2135 '
2140 CD#=JD#-4712*365.25
2145 Y=INT(CD#/365.25)
2150 RD=CD#-Y*365.25
2155 IF RD>INT(RD) THEN RD=INT(RD)+1
2160 IF Y MOD 4=0 THEN LJ=1 ELSE LJ=0
2165 IF (LJ=1)*(RD<60) THEN YD=RD+1 ELSE YD=RD
2170 IF (LJ=1)*(RD=59) THEN M$="Feb": D=29: GOTO 2235
2175 IF YD<32 THEN M$="Jan": D=YD: GOTO 2235
2180 IF YD<60 THEN M$="Feb": D=YD-31: GOTO 2235
2185 IF YD<91 THEN M$="Mar": D=YD-59: GOTO 2235
2190 IF YD<121 THEN M$="Apr": D=YD-90: GOTO 2235
2195 IF YD<152 THEN M$="May": D=YD-120: GOTO 2235
2200 IF YD<182 THEN M$="Jun": D=YD-151: GOTO 2235
2205 IF YD<213 THEN M$="Jul": D=YD-181: GOTO 2235
2210 IF YD<244 THEN M$="Aug": D=YD-212: GOTO 2235
2215 IF YD<274 THEN M$="Sep": D=YD-243: GOTO 2235
2220 IF YD<305 THEN M$="Oct": D=YD-273: GOTO 2235
2225 IF YD<335 THEN M$="Nov": D=YD-304: GOTO 2235
2230 IF YD<366 THEN M$="Dec": D=YD-334
2235 '
2240 JD$="JD"+STR$(JD#)+".  "
2245 Y$=STR$(Y): IF Y<0 THEN Y$=" "+Y$
2250 D$=STR$(D)
2255 JC$="Julian"+Y$+" "+M$+D$+".  "
2260 '
2265 DS=INT(Y/100)-2
2270 GR=INT(DS*.75+.25)
2275 IF (Y MOD 4=0)*(Y MOD 100<>0) OR Y MOD 400=0 THEN LG=1 ELSE LG=0
2280 IF (LJ=1)*(LG=0)*(RD<60) THEN GR=GR-1
2285 GYD=YD+GR: GY=Y
2290 IF (LG=1)*(RD>(59-GR))*(RD<60) THEN GYD=GYD-1
2295 IF GYD>365 THEN GYD=GYD-365: GY=Y+1
2300 IF GYD<0 THEN GYD=GYD+365: GY=GY-1
2305 IF (LG=1)*(RD=59-GR) THEN GM$="Feb": GD=29: GOTO 2370
2310 IF GYD<32 THEN GM$="Jan": GD=GYD: GOTO 2370
2315 IF GYD<60 THEN GM$="Feb": GD=GYD-31: GOTO 2370
2320 IF GYD<91 THEN GM$="Mar": GD=GYD-59: GOTO 2370
2325 IF GYD<121 THEN GM$="Apr": GD=GYD-90: GOTO 2370
2330 IF GYD<152 THEN GM$="May": GD=GYD-120: GOTO 2370
2335 IF GYD<182 THEN GM$="Jun": GD=GYD-151: GOTO 2370
2340 IF GYD<213 THEN GM$="Jul": GD=GYD-181: GOTO 2370
2345 IF GYD<244 THEN GM$="Aug": GD=GYD-212: GOTO 2370
2350 IF GYD<274 THEN GM$="Sep": GD=GYD-243: GOTO 2370
2355 IF GYD<305 THEN GM$="Oct": GD=GYD-273: GOTO 2370
2360 IF GYD<335 THEN GM$="Nov": GD=GYD-304: GOTO 2370
2365 IF GYD<366 THEN GM$="Dec": GD=GYD-334
2370 '
2375 GY$=STR$(GY): IF GY<0 THEN GY$=" "+GY$
2380 GD$=STR$(GD)
2385 GC$="Gregorian"+GY$+" "+GM$+GD$+".  "
2390 '
2395 GR$=STR$(GR): GR$=RIGHT$(GR$,LEN(GR$)-1)
2400 IF GR<0 THEN GR$="-"+GR$ ELSE IF GR>0 THEN GR$="+"+GR$
2405 GR$="Gr.Corr.= "+GR$+"."
2410 '-------------------------------------------------------------------------
2415 '               Lunar determinations, from Julian Day Number
2420 '                    Variables:  JD#, NL, D, NN, P, E$.     
2425 '
2430 NL=(JD#-2002685#)/29.530588#:  REM 9.17.0.0.0
2435 MA=INT((NL-INT(NL))*2953.0588#+.5)/100
2440 MA$=STR$(MA): MA$=RIGHT$(MA$,LEN(MA$)-1)
2445 IF (MA>-1)*(MA<1) THEN MA$="0"+MA$
2450 MA$="Moon "+MA$+"d;  "
2455 '
2460 NN=(JD#-2009802#)/173.31:  REM 9.17.19.13.17 (POCO UINIC)
2465 P=INT((NN-INT(NN))*17331+.5)/100
2470 IF P>86.655 THEN P=P-173.31
2475 IF P<0 THEN P=-(INT((100*ABS(P)+.5))/100)
2480 P$=STR$(P): P$=RIGHT$(P$,LEN(P$)-1)
2485 IF (P>-1)*(P<1) THEN P$="0"+P$
2490 IF P<0 THEN P$="-"+P$ ELSE P$="+"+P$
2495 P$="Abn.dist.= "+P$+"d."
2500 '
2505 IF (MA<1 OR MA>28.53)*(ABS(P)<15) THEN ECL$=" (Ecl.?)" ELSE ECL$=""
2510 '
2515 '-------------------------------------------------------------------------
2520 '                    Venus.   Variables:  JD#, NV, VEN
2525 '
2530 NV=(JD#-2062521#)/583.92:  REM 10.5.6.4.0 minus 4 days
2535 VEN=INT((NV-INT(NV))*583.92+.5)
2540 IF VEN>292 THEN VEN=VEN-584
2545 '
2550 VEN$=STR$(VEN): VEN$=RIGHT$(VEN$,LEN(VEN$)-1)
2555 IF VEN<0 THEN VEN$="-"+VEN$ ELSE IF VEN>0 THEN VEN$="+"+VEN$
2560 VEN$="Venus: "+VEN$+".  "
2565 '
2570 '-------------------------------------------------------------------------
2575 '                   Jupiter.   Variables:  JD#, NJ, JUP
2580 '
2585 NJ=(JD#-1970018#)/398.88
2590 JUP=INT((NJ-INT(NJ))*39888!+.5)/100
2595 IF JUP>199.44 THEN JUP=JUP-398.88
2600 JUP=INT(JUP+.5)
2605 '
2610 JUP$=STR$(JUP): JUP$=RIGHT$(JUP$,LEN(JUP$)-1)
2615 IF JUP<0 THEN JUP$="-"+JUP$ ELSE IF JUP>0 THEN JUP$="+"+JUP$
2620 JUP$="Jupiter: "+JUP$+".  "
2625 '
2630 '-------------------------------------------------------------------------
2635 '                    Saturn.   Variables:  JD#, NS, SAT
2640 '
2645 NS=(JD#-2071129#)/378.09
2650 SAT=INT((NS-INT(NS))*37809!+.5)/100
2655 IF SAT>189.045 THEN SAT=SAT-378.09
2660 SAT=INT(SAT+.5)
2665 '
2670 SAT$=STR$(SAT): SAT$=RIGHT$(SAT$,LEN(SAT$)-1)
2675 IF SAT<0 THEN SAT$="-"+SAT$ ELSE IF SAT>0 THEN SAT$="+"+SAT$
2680 SAT$="Saturn: "+SAT$+".  "
2685 '
2690 GOTO 2695
2695 '-------------------------------------------------------------------------
2700 '                            Print Routines
2705 '
2710 PRINT
2715 '
2720 MAYA$=LC$+CR$+G$+MA$+P$+ECL$
2725 EURO$=JD$+JC$+GC$+GR$
2730 PLAN$=VEN$+JUP$+SAT$
2735 '
2740 ON PR GOTO 2750,2775,2750
2745 '
2750 PRINT MAYA$
2755 PRINT EURO$
2760 PRINT PLAN$
2765 IF PR=1 THEN 2820 ELSE 2795
2770 '
2775 LPRINT MAYA$
2780 LPRINT EURO$
2785 LPRINT PLAN$
2790 LPRINT:  GOTO 2820
2795 '
2800 PRINT#2,""
2805 PRINT#2,MAYA$
2810 PRINT#2,EURO$
2815 PRINT#2,PLAN$
2820 '
2825 IF DTTP=1 THEN 450
2830 IF DTTP=2 THEN NCR=NCR+1: X=X+1: GOTO 800
2835 IF DTTP=3 THEN 1125
2840 IF (DTTP=4)*(S=2) THEN X=X+1: GOTO 1345
2845 IF DTTP=5 THEN 845
2850 IF DTTP=6 THEN 1040
2855 IF DTTP=7 OR DTTP=8 THEN 3055
2860 '
2865 IF PR=1 THEN 3055
2870 '-------------------------------------------------------------------------
2875 '         Brief Text Program (for labels and remarks in printout)
2880 '                   Variables:  TXT$, CH$, CHL, CHT, LT
2885 '
2895 CHL=0: CHT=0:  '(CHL counts characters per print line; CHT is total.)
2900 PRINT STRING$(78,45)
2905 PRINT "Enter text.   Press RETURN on or before the 255th character.   Then continue"
2910 PRINT "              in the same manner.   At end of text, type  \  to terminate the"
2915 PRINT "              demand for further text input."
2920 PRINT:PRINT"  ---or type  \  and press RETURN to retrieve other options now."
2925 LINE INPUT TXT$
2930 LT=LEN(TXT$)
2935 '
2940 FOR I=1 TO LT
2945 CH$=MID$(TXT$,I,1)
2950 IF CH$="\" THEN CH$=CHR$(13)+CHR$(10): PRINT: GOTO 3055
2955 '
2960 IF CH$=CHR$(9) THEN CH$=CHR$(13)+CHR$(10)+STRING$(5,32): CHL=4
2965 IF (CH$=CHR$(32))*(CHL>70) THEN CH$=CHR$(13)+CHR$(10): CHL=0
2970 IF (CHL<4)*(CH$=" ") THEN CH$="": GOTO 2970
2975 '
2980 ON PR GOTO 2985,2990,2995
2985 PRINT CH$;: GOTO 3000
2990 LPRINT CH$;: GOTO 3000
2995 PRINT#2,CH$;
3000 CHL=CHL+1: CHT=CHT+1
3005 '
3010 NEXT
3015 IF PR=3 THEN PRINT "CONTINUE"
3020 GOTO 2925
3025 '
3030 '-------------------------------------------------------------------------
3035 '                               Next Move
3040 '
3045 WIDTH 255
3050 WIDTH LPRINT 80
3055 PRINT STRING$(78,45)
3060 PRINT"Next--> Enter  1 if LC,    2 if CR,    3 if EUR,    4 if JDN,"
3065 PRINT"               5 if RD,    6 if SD,    7 if +DN,    8 if -DN,"
3070 PRINT"               9 if TXT,  10 to DOS,  11 to MAYACAL."
3075 '
3080 INPUT DTTP:  ON DTTP GOTO 335,580,1125,1285,845,1040,1665,1665,2870,3090,3085
3085 RUN "MAYACAL"
3090 SYSTEM
3095 '
3100 '--------------------------------------------------------------------------
